/********************************************************/
/*                                                      */
/*               OO7 Benchmark                          */
/*                                                      */
/*              COPYRIGHT (C) 1993                      */
/*                                                      */
/*                Michael J. Carey 		        */
/*                David J. DeWitt 		        */
/*                Jeffrey Naughton 		        */
/*               Madison, WI U.S.A.                     */
/*                                                      */
/*	         ALL RIGHTS RESERVED                    */
/*                                                      */
/********************************************************/


#include <libc.h>
#include <string.h>
#include <stdio.h>

#include "OO7.hxx"
#include "GenParams.h"
#include "BenchParams.h"
#include "VarParams.h"

//////////////////////////////////////////////////////////////////
//
// Query #3 - 10% selection on AtomicParts via build date (the
// most recent 10% of AtomicParts.)   The actual percentage
// is determined by the constant Query3Percent.  This may
// be varied as we gain experience with the benchmark - the
// goal is to check out if the "optimizer" is smart enough
// to properly choose between B+ tree and scan. 
//
/////////////////////////////////////////////////////////////////

extern int	debugMode;

//////////////////////////////////////////////////////////////////
//
// Routine to do Query #3
//
//////////////////////////////////////////////////////////////////


int query3()
{
  // choose a range of dates with the appropriate selectivity

  int dateRange = (Query3Percent * (MaxAtomicDate - MinAtomicDate)) / 100;
  int lastDate = MinAtomicDate + dateRange;

  if (debugMode) {
    printf("    Running Query3 with dateRange = %d, lowerDate = %d\n",
	   dateRange, lastDate);
  }

  int count = 0;
  int first = AtomicPart::extent_date->key(MinAtomicDate) ;
  int last = AtomicPart::extent_date->key(lastDate) ;
  int max = (TotalAtomicParts * Query3Percent) / 100 ;
  Iterator<AtomicPart> iter(*AtomicPart::extent_date, first, last);

  for (; iter.more(); iter.next()) {
    AtomicPart* atom = iter.get() ;
    if (debugMode) {
      printf("    In Query2, partId = %d, buildDate = %d\n",
	     atom->id, atom->buildDate);
    }
    atom->DoNothing();
    if (count++ == max) {
      break ;
    }
	
  }
  return count;
}
